@@ -54,7 +54,7 @@ use overload;
 
 #  Version information
 #
-$VERSION='1.240';
+$VERSION='1.241';
 
 
 #  Debug load
@@ -825,9 +825,30 @@ sub init_class {
     # CGI::->method is needed because perl 5.6.0 will use WebDyne::CGI->method instead of
     # CGI->method. CGI::->method makes it happy
     CGI::->import('-no_xhtml', '-no_sticky');
+    #  Work around changes in compile method in CGI ver 4.14 and later
+    #
     my @cgi_compile=qw(:all area map unescapeHTML form col colgroup spacer nobr);
-    CGI::->compile(@cgi_compile);
-    foreach (grep { !/^:/ } @cgi_compile) { map { CGI::->$_ } ("start_${_}", "end_${_}") }
+    if (UNIVERSAL::can('CGI', '_tag_func')) {
+        #  New CGI. shift off ':all'; and create shortcuts for legacy tags
+        shift @cgi_compile;
+        foreach my $function (@cgi_compile) {
+            unless (UNIVERSAL::can('CGI', $function)) { 
+                *{"CGI::${function}"} = sub { return CGI::_tag_func($function,@_); };
+            }
+            foreach my $start_end ( qw/ start end / ) {
+                my $start_end_function = "${start_end}_${function}";
+                unless (UNIVERSAL::can('CGI', $start_end_function)) { 
+                    *{"CGI::${start_end_function}"} = sub { return CGI::_tag_func($start_end_function,@_); };
+                }
+            }
+        }
+    }
+    else {
+        #  Old CGI
+        #
+        CGI::->compile(@cgi_compile);
+        foreach (grep { !/^:/ } @cgi_compile) { map { CGI::->$_ } ("start_${_}", "end_${_}") }
+    }
 
 
     #  Make all errors non-fatal
@@ -913,7 +934,7 @@ sub init_class {
             debug("eval call complete, $@, %s", Dumper(\@eval)); 
 
         };
-        if (!@eval || $@ || !$eval[0]) {
+        if (!@eval || $@ || !defined($eval[0])) {
 
             #  An error occurred - handle it and return.
             #
@@ -2994,6 +3015,7 @@ sub CGI_param_expand {
     #
     my $cgi_or=shift() ||
         return err("unable to get CGI object");
+    local $CGI::LIST_CONTEXT_WARN=0;
     foreach my $param (grep /=/, $cgi_or->param()) {
         my(@pairs) = split(/[&;]/,$param);
         foreach my $pair (@pairs) {
